/* Compatibility functions for Berkeley DB 3.
   Copyright (C) 2000 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the GNU C Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

#include <assert.h>
#include <db.h>
#include <fcntl.h>

#if DB_VERSION_MAJOR > 2

#include "db-compat.h"

int
db_open (const char *file, DBTYPE type, u_int32_t flags, int mode,
	 DB_ENV *dbenv, void *dbinfo, DB **dbp)
{
  DB *db;
  int err;

  assert (dbinfo == NULL);

  err = db_create (&db, dbenv, 0);
  if (err)
    return err;

  err = (db->open) (db, NULL, file, NULL, type, flags, mode);
  /* Make sure we upgrade, in case this is an older database */
  if (err == DB_OLD_VERSION) {
    db->close (db, 0);
    err = db->upgrade(db, file, 0);
    if (err)
      return err;
    err = (db->open) (db, NULL, file, NULL, type, flags, mode);
  }
  if (err)
    {
      db->close (db, 0);
      return err;
    }

  *dbp = db;
  return 0;
}

#endif
